..
    Copyright (C) 2020-2021 Graz University of Technology.

    invenio-theme-iform is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

Invenio module for iform theme.

- cian hughes <cian.hughes@dcu.ie>

Forked from https://github.com/tu-graz-library/invenio-theme-tugraz
